@@ -26,7 +26,6 @@
 #include <gtk/gtkobject.h>
 #include <gtk/gtktypeutils.h>
 #include <gtk/gtkmarshal.h>
-#include "yelp-section.h"
 
 #define YELP_TYPE_HTML        (yelp_html_get_type ())
 #define YELP_HTML(o)          (GTK_CHECK_CAST ((o), YELP_TYPE_HTML, YelpHtml))
@@ -71,11 +70,13 @@ void            yelp_html_close          (YelpHtml    *html);
 
 GtkWidget *     yelp_html_get_widget     (YelpHtml    *html);
 
-void            yelp_html_find           (YelpHtml    *html,
+gboolean        yelp_html_find           (YelpHtml    *html,
 					  const gchar *str,
 					  gboolean     match_case,
 					  gboolean     wrap,
 					  gboolean     forward);
+void            yelp_html_jump_to_anchor (YelpHtml    *html,
+					  gchar       *anchor);
 
 #endif /* __YELP_HTML_H__ */
 
